@@ -1,7 +1,5 @@
 package Net::Amazon::S3::Client;
-{
-  $Net::Amazon::S3::Client::VERSION = '0.60';
-}
+$Net::Amazon::S3::Client::VERSION = '0.82';
 use Moose 0.85;
 use HTTP::Status qw(is_error status_message);
 use MooseX::StrictConstructor 0.16;
@@ -9,7 +7,7 @@ use Moose::Util::TypeConstraints;
 
 # ABSTRACT: An easy-to-use Amazon S3 client
 
-type 'Etag' => where { $_ =~ /^[a-z0-9]{32}$/ };
+type 'Etag' => where { $_ =~ /^[a-z0-9]{32}(?:-\d+)?$/ };
 
 type 'OwnerId' => where { $_ =~ /^[a-z0-9]{64}$/ };
 
@@ -17,6 +15,8 @@ has 's3' => ( is => 'ro', isa => 'Net::Amazon::S3', required => 1 );
 
 __PACKAGE__->meta->make_immutable;
 
+sub bucket_class { 'Net::Amazon::S3::Client::Bucket' }
+
 sub buckets {
     my $self = shift;
     my $s3   = $self->s3;
@@ -37,7 +37,7 @@ sub buckets {
         $xpc->findnodes('/s3:ListAllMyBucketsResult/s3:Buckets/s3:Bucket') )
     {
         push @buckets,
-            Net::Amazon::S3::Client::Bucket->new(
+            $self->bucket_class->new(
             {   client => $self,
                 name   => $xpc->findvalue( './s3:Name', $node ),
                 creation_date =>
@@ -54,7 +54,7 @@ sub buckets {
 sub create_bucket {
     my ( $self, %conf ) = @_;
 
-    my $bucket = Net::Amazon::S3::Client::Bucket->new(
+    my $bucket = $self->bucket_class->new(
         client => $self,
         name   => $conf{name},
     );
@@ -67,7 +67,7 @@ sub create_bucket {
 
 sub bucket {
     my ( $self, %conf ) = @_;
-    return Net::Amazon::S3::Client::Bucket->new(
+    return $self->bucket_class->new(
         client => $self,
         %conf,
     );
@@ -132,13 +132,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Client - An easy-to-use Amazon S3 client
 
 =head1 VERSION
 
-version 0.60
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -161,7 +163,7 @@ version 0.60
   my $bucket = $client->create_bucket(
     name                => $bucket_name,
     acl_short           => 'private',
-    location_constraint => 'US',
+    location_constraint => 'us-east-1',
   );
 
   # or use an existing bucket
@@ -204,7 +206,7 @@ may change.
   my $bucket = $client->create_bucket(
     name                => $bucket_name,
     acl_short           => 'private',
-    location_constraint => 'US',
+    location_constraint => 'us-east-1',
   );
 
 =head2 bucket
@@ -213,13 +215,19 @@ may change.
   # returns a L<Net::Amazon::S3::Client::Bucket> object
   my $bucket = $client->bucket( name => $bucket_name );
 
+=head2 bucket_class
+
+  # returns string "Net::Amazon::S3::Client::Bucket"
+  # subclasses will want to override this.
+  my $bucket_class = $client->bucket_class
+
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
