@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Request::CompleteMultipartUpload;
-$Net::Amazon::S3::Request::CompleteMultipartUpload::VERSION = '0.80';
+$Net::Amazon::S3::Request::CompleteMultipartUpload::VERSION = '0.82';
 use Moose 0.85;
 use Digest::MD5 qw/md5 md5_hex/;
 use MIME::Base64;
@@ -8,7 +8,8 @@ use XML::LibXML;
 
 extends 'Net::Amazon::S3::Request';
 
-has 'bucket'        => ( is => 'ro', isa => 'BucketName', required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
+
 has 'etags'         => ( is => 'ro', isa => 'ArrayRef',   required => 1 );
 has 'key'           => ( is => 'ro', isa => 'Str',        required => 1 );
 has 'part_numbers'  => ( is => 'ro', isa => 'ArrayRef',   required => 1 );
@@ -49,13 +50,12 @@ sub http_request {
     };
 
     #build signed request
-    return Net::Amazon::S3::HTTPRequest->new( #See patch below
-        s3      => $self->s3,
+    return $self->_build_http_request(
         method  => 'POST',
         path    => $self->_uri( $self->key ). '?uploadId='.$self->upload_id,
         content => $content,
         headers => $header_spec,
-    )->http_request;
+    );
 }
 
 1;
@@ -70,7 +70,7 @@ Net::Amazon::S3::Request::CompleteMultipartUpload - An internal class to complet
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -95,11 +95,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
