@@ -1,14 +1,15 @@
 package Net::Amazon::S3::Request::CreateBucket;
-$Net::Amazon::S3::Request::CreateBucket::VERSION = '0.80';
+$Net::Amazon::S3::Request::CreateBucket::VERSION = '0.82';
 use Moose 0.85;
 extends 'Net::Amazon::S3::Request';
 
 # ABSTRACT: An internal class to create a bucket
 
-has 'bucket'    => ( is => 'ro', isa => 'BucketName',      required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
+
 has 'acl_short' => ( is => 'ro', isa => 'Maybe[AclShort]', required => 0 );
 has 'location_constraint' =>
-    ( is => 'ro', isa => 'Maybe[LocationConstraint]', required => 0 );
+    ( is => 'ro', isa => 'MaybeLocationConstraint', coerce => 1, required => 0 );
 
 __PACKAGE__->meta->make_immutable;
 
@@ -21,22 +22,21 @@ sub http_request {
         : {};
 
     my $content = '';
-    if ( defined $self->location_constraint
-        && $self->location_constraint eq 'EU' )
-    {
+    if ( defined $self->location_constraint &&
+         $self->location_constraint ne 'us-east-1') {
         $content
             = "<CreateBucketConfiguration><LocationConstraint>"
             . $self->location_constraint
             . "</LocationConstraint></CreateBucketConfiguration>";
     }
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3      => $self->s3,
+    return $self->_build_http_request(
         method  => 'PUT',
-        path    => $self->bucket . '/',
+        path    => $self->_uri,
         headers => $headers,
         content => $content,
-    )->http_request;
+        region  => 'us-east-1',
+    );
 }
 
 1;
@@ -53,7 +53,7 @@ Net::Amazon::S3::Request::CreateBucket - An internal class to create a bucket
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -78,11 +78,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
