@@ -1,22 +1,21 @@
 package Net::Amazon::S3::Request::DeleteBucket;
-$Net::Amazon::S3::Request::DeleteBucket::VERSION = '0.80';
+$Net::Amazon::S3::Request::DeleteBucket::VERSION = '0.82';
 use Moose 0.85;
 extends 'Net::Amazon::S3::Request';
 
 # ABSTRACT: An internal class to delete a bucket
 
-has 'bucket' => ( is => 'ro', isa => 'BucketName', required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
 
 __PACKAGE__->meta->make_immutable;
 
 sub http_request {
     my $self = shift;
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self->s3,
+    return $self->_build_http_request(
         method => 'DELETE',
-        path   => $self->bucket . '/',
-    )->http_request;
+        path   => $self->_uri,
+    );
 }
 
 1;
@@ -33,7 +32,7 @@ Net::Amazon::S3::Request::DeleteBucket - An internal class to delete a bucket
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -56,11 +55,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
