@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Request::DeleteMultiObject;
-$Net::Amazon::S3::Request::DeleteMultiObject::VERSION = '0.80';
+$Net::Amazon::S3::Request::DeleteMultiObject::VERSION = '0.82';
 use Moose 0.85;
 use Digest::MD5 qw/md5 md5_hex/;
 use MIME::Base64;
@@ -7,7 +7,8 @@ use Carp qw/croak/;
 
 extends 'Net::Amazon::S3::Request';
 
-has 'bucket'    => ( is => 'ro', isa => 'BucketName', required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
+
 has 'keys'      => ( is => 'ro', isa => 'ArrayRef',   required => 1 );
 
 __PACKAGE__->meta->make_immutable;
@@ -44,13 +45,12 @@ sub http_request {
     };
 
     #build signed request
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3      => $self->s3,
+    return $self->_build_http_request(
         method  => 'POST',
-        path    => $self->bucket . '/?delete',
+        path    => $self->_uri . '?delete',
         content => $content,
         headers => $header_spec,
-    )->http_request;
+    );
 }
 
 1;
@@ -65,7 +65,7 @@ Net::Amazon::S3::Request::DeleteMultiObject - An internal class to delete multip
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -89,11 +89,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
