@@ -1,12 +1,13 @@
 package Net::Amazon::S3::Request::DeleteObject;
-$Net::Amazon::S3::Request::DeleteObject::VERSION = '0.80';
+$Net::Amazon::S3::Request::DeleteObject::VERSION = '0.82';
 use Moose 0.85;
 use Moose::Util::TypeConstraints;
 extends 'Net::Amazon::S3::Request';
 
 # ABSTRACT: An internal class to delete an object
 
-has 'bucket' => ( is => 'ro', isa => 'BucketName', required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
+
 has 'key'    => ( is => 'ro', isa => 'Str',        required => 1 );
 
 __PACKAGE__->meta->make_immutable;
@@ -14,11 +15,10 @@ __PACKAGE__->meta->make_immutable;
 sub http_request {
     my $self = shift;
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self->s3,
+    return $self->_build_http_request(
         method => 'DELETE',
         path   => $self->_uri( $self->key ),
-    )->http_request;
+    );
 }
 
 1;
@@ -35,7 +35,7 @@ Net::Amazon::S3::Request::DeleteObject - An internal class to delete an object
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -59,11 +59,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
