@@ -1,23 +1,22 @@
 package Net::Amazon::S3::Request::GetBucketLocationConstraint;
-$Net::Amazon::S3::Request::GetBucketLocationConstraint::VERSION = '0.80';
+$Net::Amazon::S3::Request::GetBucketLocationConstraint::VERSION = '0.82';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
 
 # ABSTRACT: An internal class to get a bucket's location constraint
 
-has 'bucket' => ( is => 'ro', isa => 'BucketName', required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
 
 __PACKAGE__->meta->make_immutable;
 
 sub http_request {
     my $self = shift;
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self->s3,
+    return $self->_build_http_request(
         method => 'GET',
         path   => $self->_uri('') . '?location',
-    )->http_request;
+    );
 }
 
 1;
@@ -34,7 +33,7 @@ Net::Amazon::S3::Request::GetBucketLocationConstraint - An internal class to get
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -57,11 +56,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
