@@ -1,10 +1,11 @@
 package Net::Amazon::S3::Request::GetObject;
-$Net::Amazon::S3::Request::GetObject::VERSION = '0.80';
+$Net::Amazon::S3::Request::GetObject::VERSION = '0.82';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
 
-has 'bucket' => ( is => 'ro', isa => 'BucketName', required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
+
 has 'key'    => ( is => 'ro', isa => 'Str',        required => 1 );
 has 'method' => ( is => 'ro', isa => 'HTTPMethod', required => 1 );
 
@@ -15,20 +16,21 @@ __PACKAGE__->meta->make_immutable;
 sub http_request {
     my $self = shift;
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self->s3,
+    return $self->_build_http_request(
         method => $self->method,
         path   => $self->_uri( $self->key ),
-    )->http_request;
+    );
 }
 
 sub query_string_authentication_uri {
-    my ( $self, $expires ) = @_;
+    my ( $self, $expires, $query_form ) = @_;
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self->s3,
+    my $uri = URI->new( $self->_uri( $self->key ) );
+    $uri->query_form( %$query_form ) if $query_form;
+
+    return $self->_build_signed_request(
         method => $self->method,
-        path   => $self->_uri( $self->key ),
+        path   => $uri->as_string,
     )->query_string_authentication_uri($expires);
 }
 
@@ -46,7 +48,7 @@ Net::Amazon::S3::Request::GetObject - An internal class to get an object
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -75,11 +77,11 @@ This method returns query string authentication URI.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
