@@ -1,5 +1,5 @@
 package Net::Amazon::S3::Request::ListAllMyBuckets;
-$Net::Amazon::S3::Request::ListAllMyBuckets::VERSION = '0.80';
+$Net::Amazon::S3::Request::ListAllMyBuckets::VERSION = '0.82';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
@@ -10,11 +10,12 @@ __PACKAGE__->meta->make_immutable;
 
 sub http_request {
     my $self    = shift;
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self->s3,
+    return $self->_build_http_request(
         method => 'GET',
         path   => '',
-    )->http_request;
+        use_virtual_host => 0,
+        authorization_method => 'Net::Amazon::S3::Signature::V2',
+    );
 }
 
 1;
@@ -31,7 +32,7 @@ Net::Amazon::S3::Request::ListAllMyBuckets - An internal class to list all bucke
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -53,11 +54,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
