@@ -1,7 +1,5 @@
 package Net::Amazon::S3::Request::ListBucket;
-{
-  $Net::Amazon::S3::Request::ListBucket::VERSION = '0.60';
-}
+$Net::Amazon::S3::Request::ListBucket::VERSION = '0.82';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use URI::Escape qw(uri_escape_utf8);
@@ -9,7 +7,8 @@ extends 'Net::Amazon::S3::Request';
 
 # ABSTRACT: An internal class to list a bucket
 
-has 'bucket'    => ( is => 'ro', isa => 'BucketName', required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
+
 has 'prefix'    => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 has 'delimiter' => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 has 'max_keys' =>
@@ -21,7 +20,7 @@ __PACKAGE__->meta->make_immutable;
 sub http_request {
     my $self = shift;
 
-    my $path = $self->bucket . "/";
+    my $path = $self->_uri;
 
     my @post;
     foreach my $method ( qw(prefix delimiter max_keys marker) ) {
@@ -35,11 +34,10 @@ sub http_request {
         $path .= '?' . join( '&', @post );
     }
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3     => $self->s3,
+    return $self->_build_http_request(
         method => 'GET',
         path   => $path,
-    )->http_request;
+    );
 }
 
 sub _urlencode {
@@ -53,13 +51,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Amazon::S3::Request::ListBucket - An internal class to list a bucket
 
 =head1 VERSION
 
-version 0.60
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -85,11 +85,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Pedro Figueiredo <me@pedrofigueiredo.org>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
