@@ -1,12 +1,13 @@
 package Net::Amazon::S3::Request::SetObjectAccessControl;
-$Net::Amazon::S3::Request::SetObjectAccessControl::VERSION = '0.80';
+$Net::Amazon::S3::Request::SetObjectAccessControl::VERSION = '0.82';
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
 
 # ABSTRACT: An internal class to set an object's access control
 
-has 'bucket'    => ( is => 'ro', isa => 'BucketName',      required => 1 );
+with 'Net::Amazon::S3::Role::Bucket';
+
 has 'key'       => ( is => 'ro', isa => 'Str',             required => 1 );
 has 'acl_short' => ( is => 'ro', isa => 'Maybe[AclShort]', required => 0 );
 has 'acl_xml'   => ( is => 'ro', isa => 'Maybe[Str]',      required => 0 );
@@ -30,13 +31,12 @@ sub http_request {
         : {};
     my $xml = $self->acl_xml || '';
 
-    return Net::Amazon::S3::HTTPRequest->new(
-        s3      => $self->s3,
+    return $self->_build_http_request(
         method  => 'PUT',
         path    => $self->_uri( $self->key ) . '?acl',
         headers => $headers,
         content => $xml,
-    )->http_request;
+    );
 }
 
 1;
@@ -53,7 +53,7 @@ Net::Amazon::S3::Request::SetObjectAccessControl - An internal class to set an o
 
 =head1 VERSION
 
-version 0.80
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -79,11 +79,11 @@ This method returns a HTTP::Request object.
 
 =head1 AUTHOR
 
-Rusty Conover <rusty@luckydinosaur.com>
+Leo Lapworth <llap@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
+This software is copyright (c) 2018 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
